@@ -550,7 +550,7 @@ HTMLテンプレート中のフォームを解析し、中にセットされて
 引数はフォームの name="..." で指定される名前。
 省略された場合は、name属性の存在しないform要素が取り出される。
 
-対象となるノードに未置換のタグがあった場合はエラーとなる。
+対象となるノードの HTML タグの内部に未置換のタグがあった場合はエラーとなる。
 
 =item setForm
 
@@ -576,7 +576,7 @@ L<Tripletail::Form>オブジェクトの代わりにハッシュのリファレ
 しないキーの関しては、テンプレートの元のデータが
 保存される。
 
-対象となるノードに未置換のタグがあった場合はエラーとなる。
+対象となるノードの HTML タグの内部に未置換のタグがあった場合はエラーとなる。
 
 =item extForm
 
@@ -591,7 +591,7 @@ HTMLテンプレート中のフォームが外部アプリケーションに対
 通常のフォームはTLフレームワークに対するものとして、いくつかの操作が行われるが、
 extForm を行った場合はそれらの操作を行わない。
 
-対象となるノードに未置換のタグがあった場合はエラーとなる。
+対象となるノードの HTML タグの内部に未置換のタグがあった場合はエラーとなる。
 
 =item addHiddenForm
 
@@ -612,7 +612,7 @@ L<Tripletail::Form>オブジェクトの代わりにハッシュのリファレ
 渡されたフォームデータの全てのキーがhiddenとして追加される。
 既存の値に上書きはされず、 単純に追加される。
 
-対象となるノードに未置換のタグがあった場合はエラーとなる。
+対象となるノードの HTML タグの内部に未置換のタグがあった場合はエラーとなる。
 
 =item addSessionCheck
 
@@ -635,7 +635,7 @@ csrfkeyとセッションIDを利用してキーを作成する為、csrfkeyは
 第3引数に 0 または 1 を指定すると、http側、https側を指定できる。
 省略した場合は、そのときの通信が http/https のどちらであるかによって選択される。
 
-対象となるノードに未置換のタグがあった場合はエラーとなる。
+対象となるノードの HTML タグの内部に未置換のタグがあった場合はエラーとなる。
 
 =item getHtml
 
